<?php
/**
 * Sample code for the CreatePickupRequest Canada Post service.
 * 
 * The CreatePickupRequest service creates a request for a one-time on-demand pickup or to set up scheduled pickups.
 * 
 * This sample is configured to access the Developer Program sandbox environment. 
 * Use your development key username and password for the web service credentials.
 * 
 */

// Your username and password are imported from the following file
// CPCWS_Pickup_PHP_Samples\REST\pickup\user.ini
$userProperties = parse_ini_file(realpath(dirname($_SERVER['SCRIPT_FILENAME'])) . '/../user.ini');
$customerNumber = $userProperties['customerNumber'];

$wsdl = realpath(dirname($_SERVER['SCRIPT_FILENAME'])) . '/../../wsdl/pickuprequest.wsdl';

$hostName = 'ct.soa-gw.canadapost.ca';

// SOAP URI
$location = 'https://' . $hostName . '/enab/soap/pickuprequest';

// SSL Options
$opts = array('ssl' =>
	array(
		'verify_peer'=> false,
		'cafile' => realpath(dirname($_SERVER['SCRIPT_FILENAME'])) . '/../../../third-party/cert/cacert.pem',
		'CN_match' => $hostName
	)
);

$ctx = stream_context_create($opts);	
$client = new SoapClient($wsdl,array('location' => $location, 'features' => SOAP_SINGLE_ELEMENT_ARRAYS, 'stream_context' => $ctx, 'soap_version' => SOAP_1_2));

// Set WS Security UsernameToken
$WSSENS = 'http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-secext-1.0.xsd';
$usernameToken = new stdClass(); 
$usernameToken->Username = new SoapVar($userProperties['username'], XSD_STRING, null, null, null, $WSSENS);
$usernameToken->Password = new SoapVar($userProperties['password'], XSD_STRING, null, null, null, $WSSENS);
$content = new stdClass(); 
$content->UsernameToken = new SoapVar($usernameToken, SOAP_ENC_OBJECT, null, null, null, $WSSENS);
$header = new SOAPHeader($WSSENS, 'Security', $content);
$client->__setSoapHeaders($header); 

try {
	// Execute Request
	$result = $client->__soapCall('CreatePickupRequest', array(
	    'create-pickup-request-request' => array(
	    	'customer-number'	=> $customerNumber,
			'locale'			=> 'FR',
	    	'pickup-request-details' => array(
    			'pickup-type'	=> 'OnDemand',
				'pickup-location' => array(
					'business-address-flag'	=>	'true'
				),
				'contact-info' => array(
					'contact-name'	=>	'John Smith',
					'email'			=>	'john.smith@host.com',
					'contact-phone'	=>	'123-456-7890'
				),
				'location-details' => array(
					'pickup-instructions'	=>	'Door at back.'
				),
				'pickup-volume'	=> '10 parcels',
				'pickup-times' => array(
					'on-demand-pickup-time' => array(
						'date'				=>	'2015-05-22',
						'preferred-time'	=>	'12:00',
						'closing-time'		=>	'17:00'
					)
				)
	    	)
		)
	), NULL, NULL);
	
	// Parse Response
	if ( isset($result->{'pickup-request-info'}) ) {
		$header = $result->{'pickup-request-info'}->{'pickup-request-header'};
		echo "Request Id: " . $header->{'request-id'} . "\n";
		echo "Request Status: " . $header->{'request-status'} . "\n";
		echo "Pickup Type: " . $header->{'pickup-type'} . "\n";
		echo "Request Date: " . $header->{'request-date'};
	} else {
		foreach ( $result->{'messages'}->{'message'} as $message ) {
			echo 'Error Code: ' . $message->code . "\n";
			echo 'Error Msg: ' . $message->description . "\n\n";
		}
	}
} catch (SoapFault $exception) {
	echo 'Fault Code: ' . trim($exception->faultcode) . "\n"; 
	echo 'Fault Reason: ' . trim($exception->getMessage()) . "\n"; 
}

?>

